import './shim';
export interface PCKS12KeyPair {
    publicKey: string;
    privateKey: string;
    certificate: string;
}
export interface KeyPair {
    publicKey: string;
    privateKey: string;
}
export declare enum Hash {
    MD5 = 0,
    SHA1 = 1,
    SHA224 = 2,
    SHA256 = 3,
    SHA384 = 4,
    SHA512 = 5
}
export declare enum PEMCipher {
    DES = 0,
    D3DES = 1,
    AES128 = 2,
    AES192 = 3,
    AES256 = 4
}
export declare enum SaltLength {
    AUTO = 0,
    EQUALS_HASH = 1
}
export default class RSA {
    static useJSI: boolean;
    static convertJWKToPrivateKey(data: any, keyId: string): Promise<string>;
    static convertJWKToPublicKey(data: any, keyId: string): Promise<string>;
    static convertKeyPairToPKCS12(privateKey: string, certificate: string, password: string): Promise<string>;
    static convertPKCS12ToKeyPair(pkcs12: string, password: string): Promise<PCKS12KeyPair>;
    static convertPrivateKeyToPKCS8(privateKey: string): Promise<string>;
    static convertPrivateKeyToPKCS1(privateKey: string): Promise<string>;
    static convertPrivateKeyToJWK(privateKey: string): Promise<any>;
    static convertPrivateKeyToPublicKey(privateKey: string): Promise<string>;
    static convertPublicKeyToPKIX(publicKey: string): Promise<string>;
    static convertPublicKeyToPKCS1(publicKey: string): Promise<string>;
    static convertPublicKeyToJWK(publicKey: string): Promise<any>;
    static decryptPrivateKey(privateKeyEncrypted: string, password: string): Promise<string>;
    static encryptPrivateKey(privateKey: string, password: string, cipherName: PEMCipher): Promise<string>;
    static decryptOAEP(message: string, label: string, hashName: Hash, privateKey: string): Promise<string>;
    static decryptOAEPBytes(message: Uint8Array, label: string, hashName: Hash, privateKey: string): Promise<Uint8Array>;
    static decryptPKCS1v15(message: string, privateKey: string): Promise<string>;
    static decryptPKCS1v15Bytes(message: Uint8Array, privateKey: string): Promise<Uint8Array>;
    static encryptOAEP(message: string, label: string, hashName: Hash, publicKey: string): Promise<string>;
    static encryptOAEPBytes(message: Uint8Array, label: string, hashName: Hash, publicKey: string): Promise<Uint8Array>;
    static encryptPKCS1v15(message: string, publicKey: string): Promise<string>;
    static encryptPKCS1v15Bytes(message: Uint8Array, publicKey: string): Promise<Uint8Array>;
    static signPSS(message: string, hashName: Hash, saltLengthName: SaltLength, privateKey: string): Promise<string>;
    static signPSSBytes(message: Uint8Array, hashName: Hash, saltLengthName: SaltLength, privateKey: string): Promise<Uint8Array>;
    static signPKCS1v15(message: string, hashName: Hash, privateKey: string): Promise<string>;
    static signPKCS1v15Bytes(message: Uint8Array, hashName: Hash, privateKey: string): Promise<Uint8Array>;
    static verifyPSS(signature: string, message: string, hashName: Hash, saltLengthName: SaltLength, publicKey: string): Promise<boolean>;
    static verifyPSSBytes(signature: Uint8Array, message: Uint8Array, hashName: Hash, saltLengthName: SaltLength, publicKey: string): Promise<boolean>;
    static verifyPKCS1v15(signature: string, message: string, hashName: Hash, publicKey: string): Promise<boolean>;
    static verifyPKCS1v15Bytes(signature: Uint8Array, message: Uint8Array, hashName: Hash, publicKey: string): Promise<boolean>;
    static hash(message: string, name: Hash): Promise<string>;
    static base64(message: string): Promise<string>;
    static generate(bits: number): Promise<KeyPair>;
    private static call;
    private static _bytesResponse;
    private static _stringResponse;
    private static _boolResponse;
    private static _keyPairResponse;
    private static _pkcs12KeyPairResponse;
}
//# sourceMappingURL=index.d.ts.map